pub struct GatewayEvents { /* private fields */ }Expand description
Single-owner framed event reader.
Implementations
Sourceimpl GatewayEvents
impl GatewayEvents
Sourcepub async fn next(&mut self) -> Result<Option<ServerFrame>>
pub async fn next(&mut self) -> Result<Option<ServerFrame>>
Receives the next version-checked server frame.
Errors
Returns an error if the transport fails or returns invalid data.
Sourcepub fn scoped(&mut self) -> GatewayEventScope<'_>
pub fn scoped(&mut self) -> GatewayEventScope<'_>
Starts a focused response wait without consuming unrelated gateway events.