Module command

Module command 

Command-line entrypoint shared by the gateway and CLI packages.

Structs

GatewayCli
Parsed mobius-gateway command line.

Enums

FrontendCommand
Frontend selected by a parsed gateway command line.

Functions

ensure_background_gateway
Starts the configured detached gateway unless its process is already running.
initialize_named_cloudflare
Initializes one gateway against a user-owned named Cloudflare Tunnel.
initialize_quick_cloudflare
Initializes one gateway with an account-free Cloudflare Quick Tunnel.
reset_gateway_state
Permanently removes previously confirmed gateway state after stopping its process.
run
Runs a gateway command with arguments excluding the executable name.
run_cli
Runs an already parsed gateway command.
terminate_process_group
Terminates a process group created by gateway autostart.