run

Function run 

pub async fn run(
    arguments: Vec<OsString>,
    save_local_client: fn(&Endpoint, String) -> Result<()>,
    load_local_client: fn(&Endpoint) -> Result<Option<String>>,
) -> Result<()>
Runs a gateway command with arguments excluding the executable name.

Errors

Returns an error if validation or an operation required to complete the request fails.