pub fn startup_error(
message: impl Display,
log: &NamedTempFile,
max_bytes: u64,
) -> ErrorExpand description
Adds a bounded diagnostic excerpt from a gateway startup log.
pub fn startup_error(
message: impl Display,
log: &NamedTempFile,
max_bytes: u64,
) -> ErrorAdds a bounded diagnostic excerpt from a gateway startup log.