pub struct ResolvedCredential {
pub api_key: String,
pub lifetime: ModelCredentialLifetime,
}Expand description
A credential resolved atomically with the lifetime of the same stored secret.
Fields
api_key: StringSecret used only for provider assembly.
lifetime: ModelCredentialLifetimeExpiry and revocation shared by all routes using this secret.