pub enum GatewayNotification {
Sessions,
Bots,
}Expand description
Optional gateway broadcasts a client may suppress on its connection. Approvals, session events, errors, and request responses cannot be suppressed.
Variants
Sessions
Unsolicited conversation catalog and activity updates.
Bots
Unsolicited Bot catalog updates.