HookSelector

Enum HookSelector 

pub enum HookSelector {
    Schedule {
        schedule: RoutineSchedule,
        ends_at: Option<i64>,
    },
    Event {
        source: HookSource,
        kind: HookKind,
        routine_outcome: Option<RoutineRunStatus>,
        session_outcome: Option<ExecutionOutcome>,
        custom_name: Option<String>,
    },
}
Exact trigger shared by routine bindings and reporting consumers.

Variants



Schedule

The existing schedule model, owned by this binding.

Fields

schedule: RoutineSchedule

Timer rule.

ends_at: Option<i64>

Optional cutoff.



Event

An exact source and typed boundary, with applicable outcome filters.

Fields

source: HookSource

Source identity.

kind: HookKind

Boundary.

routine_outcome: Option<RoutineRunStatus>

Optional terminal routine outcome.

session_outcome: Option<ExecutionOutcome>

Optional terminal session outcome.

custom_name: Option<String>

Optional custom event name.