Reusable async client for CLI and native frontends.
Structs
- Endpoint
- Validated plaintext-loopback, authenticated-root TLS, or WSS endpoint.
- Gateway
Client - Connected client before its command and event halves are separated.
- Gateway
Events - Single-owner framed event reader.
- Gateway
Sender - Cloneable framed command writer.
- Paired
Client - Token returned while pairing a new client.
Constants
- MAX_
PENDING_ FRAMES - Maximum number of frames a focused client flow may temporarily defer.
Functions
- token_
from_ env - Resolves the bearer token expected by the reusable CLI client.