Command-line entrypoint shared by the gateway and CLI packages.
Structs
- Gateway
Cli - Parsed
mobius-gatewaycommand line.
Enums
- Frontend
Command - Frontend selected by a parsed gateway command line.
Functions
- ensure_
background_ gateway - Starts the configured detached gateway unless its process is already running.
- initialize_
named_ cloudflare - Initializes one gateway against a user-owned named Cloudflare Tunnel.
- initialize_
quick_ cloudflare - Initializes one gateway with an account-free Cloudflare Quick Tunnel.
- reset_
gateway_ state - Permanently removes previously confirmed gateway state after stopping its process.
- run
- Runs a gateway command with arguments excluding the executable name.
- run_cli
- Runs an already parsed gateway command.
- terminate_
process_ group - Terminates a process group created by gateway autostart.